@@ -907,7 +907,7 @@ nautilus_query_editor_add_row (NautilusQueryEditor *editor,
 	row->editor = editor;
 	row->type = type;
 	
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	row->hbox = hbox;
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (editor->details->visible_vbox), hbox, FALSE, FALSE, 0);
@@ -972,11 +972,11 @@ nautilus_query_editor_init (NautilusQueryEditor *editor)
 
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (editor), GTK_ORIENTATION_VERTICAL);
 
-	editor->details->invisible_vbox = gtk_vbox_new (FALSE, 6);
+	editor->details->invisible_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (editor->details->invisible_vbox), 6);
 	gtk_box_pack_start (GTK_BOX (editor), editor->details->invisible_vbox,
 			    FALSE, FALSE, 0);
-	editor->details->visible_vbox = gtk_vbox_new (FALSE, 6);
+	editor->details->visible_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (editor->details->visible_vbox), 6);
 	gtk_box_pack_start (GTK_BOX (editor), editor->details->visible_vbox,
 			    FALSE, FALSE, 0);
@@ -984,7 +984,7 @@ nautilus_query_editor_init (NautilusQueryEditor *editor)
 	gtk_widget_show (editor->details->visible_vbox);
 
 	/* Create invisible part: */
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start (GTK_BOX (editor->details->invisible_vbox),
 			    hbox, FALSE, FALSE, 0);
 	gtk_widget_show (hbox);
@@ -1066,7 +1066,7 @@ setup_internal_entry (NautilusQueryEditor *editor)
 	char *label_markup;
 	
 	/* Create visible part: */
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (editor->details->visible_vbox), hbox, FALSE, FALSE, 0);
 
@@ -1101,7 +1101,7 @@ setup_external_entry (NautilusQueryEditor *editor, GtkWidget *entry)
 	gchar *label_markup;
 	
 	/* Create visible part: */
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (editor->details->visible_vbox), hbox, FALSE, FALSE, 0);
 
